package de.intevation.mxd.reader;

import java.io.IOException;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.PictureMarkerSymbol;
import com.esri.arcgis.display.IColor;
import com.esri.arcgis.carto.PictureElement;

import org.w3c.dom.Element;
import de.intevation.mxd.utils.MapToXMLUtils;

/**
 * Reads picture marker symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class PictureMarkerSymbolReader implements ISymbolReader{

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(PictureMarkerSymbolReader.class);

    /**
     * Private member.
     */
    private Element renderer;
    private PictureMarkerSymbol symbol;
    private MapToXMLUtils util;


    public PictureMarkerSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof PictureMarkerSymbol) {
            this.symbol = (PictureMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a PictureMarkerSymbol!");
        }
    }

    /**
     * Setter for the parent XML element.
     *
     * @param parent The XML parent node.
     */
    public void setParent(Element parent) {
        this.renderer = parent;
    }

    /**
     * Setter for XML document helper.
     *
     * @param util The helper class for storing map information.
     */
    public void setUtil(MapToXMLUtils util) {
        this.util = util;
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws IOException {
        logger.debug("read()");
        Element symbolElement;
        try {
            symbolElement = util.addSymbol(renderer);
        }
        catch(Exception e) {
            e.printStackTrace();
            return null;
        }

        symbolElement.setAttribute(
            "angle",
            String.valueOf(symbol.getAngle()));
        symbolElement.setAttribute(
            "size",
            String.valueOf(symbol.getSize()));
        symbolElement.setAttribute(
            "x_offset",
            String.valueOf(symbol.getXOffset()));
        symbolElement.setAttribute(
            "y_offset",
            String.valueOf(symbol.getYOffset()));
        symbolElement.setAttribute(
            "name",
            symbol.getNameString());
        PictureElement pElem = new PictureElement();
        pElem.importPicture(symbol.getPicture());
        System.out.println("Path:" + pElem.getPath());
        symbolElement.setAttribute("style", "picture");
        return symbolElement;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
